#!/usr/bin/perl -sw
##
## Razor::Agent -- UI routines for razor agents.
##
## Copyright (c) 2001, Vipul Ved Prakash.  All rights reserved.
## This code is free software; you can redistribute it and/or modify
## it under the same terms as Perl itself.
##
## $Id: Agent.pm,v 1.2 2001/11/28 02:58:52 vipul Exp $

package Razor::Agent;

use lib qw(lib);
use strict;
use Razor::Client;
use Getopt::Long; 
use Razor::String qw(hash);
use Data::Dumper;
use base qw(Razor::Client);


sub options { 
    my ($agent) = @_;
    my %self;
    my @sigs;
    Getopt::Long::Configure ("no_ignore_case");
    GetOptions(
        's'   => \$self{simulate},
        'd'   => \$self{debug},
  'verbose'   => \$self{debug},
        'v'   => \$self{version},
        'h'   => \$self{usage},
        'H'   => \$self{printhash},
      'sig'   => \$self{sig},
        'S'   => \$self{sig},
     'mbox'   => \$self{mbox},
        'M'   => \$self{mbox},
        'n'   => \$self{negative},
   'conf=s'   => \$self{config},
 'config=s'   => \$self{config},
        'f'   => \$self{foreground},
    );
    if ($self{usage}) { 
        print "$agent [-s] [-d] [-H] [-M] [-h] [-conf=filename] filename | mbox | signatures\n";
        print "             -s  Simulate Only.\n";
        print "             -d  Turn on debugging.\n";
        print "             -H  Compute and print signature.\n";
        print "             -f  Stay in foreground.\n" if $agent eq "razor-report";
        print "    -S |  --sig  Accept a lists of signatures to check on the command line\n";
        print "    -M | --mbox  Accept a mailbox name on the command line\n";
        print "             -v  Print version number and exit\n";
        print "             -h  Print this usage message.\n";
        print "see $agent(1) manpage for details.\n";
        exit 1;
    } elsif ($self{mbox} && $self{sig}) { 
        print "--mbox and --sig are mutually exclusive.\n";
        exit 1;
    } elsif ($self{version}) { 
        print "Razor Client Tools $Razor::Client::VERSION, protocol version $Razor::Version::PROTOCOL\n"; 
        exit 1 
    } elsif ($self{sig})  { 
        push @sigs, @ARGV;
#    } elsif ($self{mbox}) { 
#        my $mbox = shift @ARGV; 
#        open MBOX, $mbox || die $!;
#        { 
#            $/ = "\n\nFrom ";
#            my $mess;
#            while ($mess = <MBOX>) { 
#                my @message = split /\n/, $mess;
#                push @sigs, hash(\@message);
#            }
#        }
#        close MBOX;
#        $self{sig} = 1;
#        $/ = "\n";
# replaced by nick mossie's patch
    } elsif ($self{mbox}) {
        my $mbox = shift @ARGV;
        open MBOX, $mbox || die $!;
        {
            my @mailbox = <MBOX>;
            close MBOX;
            my $line;
            my @message;
            foreach $line (@mailbox) {
                if ($line =~ /^From / && $mailbox[0] ne $line) {
                    push @sigs, hash(\@message);
                    splice @message;
                    push @message, $line;
                } else {
                    push @message, $line;
                }
            }    
            push @sigs, hash(\@message);
         }
         $self{sig} = 1;
    } else { 
        my @spam = <>; 
        push @sigs, hash(\@spam);
    }
    if ($self{printhash}) { 
        $" = "\n"; print "@sigs\n";
        exit 1;
    }
    return (\%self, @sigs);
}


sub raise_error { 
    my $self = shift;
    my $str = $self->errstr();
    my ($code) = $str =~ /Razor Error (\d+):/;
    $code = 255 unless $code; 
    print "FATAL: $str";
    exit $code;
}


1;


